# coding: utf-8

from distutils.core import setup


setup(
    packages=['yased'],
    package_dir={'yased': 'src/yased'},
    name='yased',
    version='0.0.1',
    description='Yet another simplest events dispatcher',
    author='Pavel Patrin',
    author_email='pavelpat@ya.ru',
    url='https://github.com/pavelpat/yased'
)
